@@ -39,6 +39,37 @@ def query2(company: str):
             }"
 
 
+def query3(product: str):
+    """
+    Given a product, it returns the cpu type of that product
+    :param product:
+    :return: cpu type of that product
+    """
+    return "PREFIX wd: <http://www.wikidata.org/entity/>\
+            PREFIX wdt: <http://www.wikidata.org/prop/direct/>\
+            PREFIX rdfs: <http://www.w3.org/2000/01/rdf-schema#>\
+            PREFIX sipg: <https://evilscript.altervista.org/productCatalog.owl#>\
+            SELECT ?prod ?cpu WHERE {\
+            ?device sipg:CpuType ?cpu.\
+            SERVICE <https://query.wikidata.org/sparql> {\
+                ?chip wdt:P31 wd:Q610398;\
+                rdfs:label ?label;\
+                wdt:P1535 ?prod.\
+            FILTER (?device = sipg:" + product + " && lang(?label) = 'it' && regex(?label, ?cpu)).\
+            }\
+            }"
+
+
+def query4(person: str):
+    return "PREFIX rdf: <http://www.w3.org/1999/02/22-rdf-syntax-ns#>\
+            PREFIX sipg: <https://evilscript.altervista.org/productCatalog.owl#>\
+            SELECT ?prod WHERE{\
+                ?user rdf:type sipg:User;\
+                sipg:buysProduct ?prod.\
+                FILTER (?user = sipg:" + person + ")\
+            }"
+
+
 def show_results(results: dict, opt_column: str):
     if opt_column == "":
         colonna = input("Inserisci il nome della colonne che vuoi visualizzare, separate da una virgola: ").split(",")
@@ -142,5 +173,23 @@ def query_from_text():
             num = num + 1
 
 
+@app.command()
+def myproducts(user: str):
+    """
+    Takes the user and returns all the products
+    that the user bought from the productCatalog
+    """
+    do_query(query4(user), "prod")
+
+
+@app.command()
+def cputype(product: str):
+    """
+    Takes the product name and returns the
+    CPU type of the product from WikiData
+    """
+    do_query(query3(product), "prod,cpu")
+
+
 if __name__ == '__main__':
     app()
